==> libmemcached-0.49.tar.gz: libmemcached-0.49/tests/error_conditions.cc <==
/*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 * 
 *  Libmemcached
 *
 *  Copyright (C) 2011 Data Differential, http://datadifferential.com/
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *      * Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *      * Redistributions in binary form must reproduce the above
 *  copyright notice, this list of conditions and the following disclaimer
 *  in the documentation and/or other materials provided with the
 *  distribution.
 *
 *      * The names of its contributors may not be used to endorse or
 *  promote products derived from this software without specific prior
 *  written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <config.h>

#define BUILDING_LIBMEMCACHED

#include <libmemcached/memcached.h>
#include <libmemcached/is.h>
#include <libtest/test.h>
#include <tests/error_conditions.h>

#ifdef	__cplusplus
extern "C" {
#endif

test_return_t memcached_increment_MEMCACHED_NO_SERVERS(memcached_st *junk)
{
  (void)junk;
  memcached_st *memc_ptr;

  memc_ptr= memcached_create(NULL);
  test_true(memc_ptr);

  memcached_increment(memc_ptr, memcached_string_with_size("dead key"), 1, NULL);
  test_true(memcached_last_error(memc_ptr) == MEMCACHED_NO_SERVERS);

  memcached_increment(memc_ptr, memcached_string_with_size("dead key"), 1, NULL);
  test_true(memcached_last_error(memc_ptr) == MEMCACHED_NO_SERVERS);

  memcached_free(memc_ptr);

  return TEST_SUCCESS;
}

#ifdef	__cplusplus
}
#endif

==> libmemcached-0.50.tar.gz: libmemcached-0.50/tests/error_conditions.cc <==
/*  vim:expandtab:shiftwidth=2:tabstop=2:smarttab:
 * 
 *  Libmemcached
 *
 *  Copyright (C) 2011 Data Differential, http://datadifferential.com/
 *  All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are
 *  met:
 *
 *      * Redistributions of source code must retain the above copyright
 *  notice, this list of conditions and the following disclaimer.
 *
 *      * Redistributions in binary form must reproduce the above
 *  copyright notice, this list of conditions and the following disclaimer
 *  in the documentation and/or other materials provided with the
 *  distribution.
 *
 *      * The names of its contributors may not be used to endorse or
 *  promote products derived from this software without specific prior
 *  written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#include <config.h>

#define BUILDING_LIBMEMCACHED

#include <libmemcached/memcached.h>
#include <libmemcached/is.h>
#include <libtest/test.h>
#include <tests/error_conditions.h>

test_return_t memcached_increment_MEMCACHED_NO_SERVERS(memcached_st *)
{
  memcached_st *memc_ptr;

  memc_ptr= memcached_create(NULL);
  test_true(memc_ptr);

  memcached_increment(memc_ptr, memcached_literal_param("dead key"), 1, NULL);
  test_true(memcached_last_error(memc_ptr) == MEMCACHED_NO_SERVERS);

  memcached_increment(memc_ptr, memcached_literal_param("dead key"), 1, NULL);
  test_true(memcached_last_error(memc_ptr) == MEMCACHED_NO_SERVERS);

  memcached_free(memc_ptr);

  return TEST_SUCCESS;
}
